@@ -3,9 +3,18 @@
 #ifndef cmCMakeHostSystemInformationCommand_h
 #define cmCMakeHostSystemInformationCommand_h
 
+#include "cmConfigure.h"
+
+#include <stddef.h>
+#include <string>
+#include <vector>
+
 #include "cmCommand.h"
 
-#include <cmsys/SystemInformation.hxx>
+class cmExecutionStatus;
+namespace cmsys {
+class SystemInformation;
+} // namespace cmsys
 
 /** \class cmCMakeHostSystemInformationCommand
  * \brief Query host system specific information
@@ -31,21 +40,6 @@ public:
   bool InitialPass(std::vector<std::string> const& args,
                    cmExecutionStatus& status) CM_OVERRIDE;
 
-  /**
-  * This determines if the command is invoked when in script mode.
-  */
-  bool IsScriptable() const CM_OVERRIDE { return true; }
-
-  /**
-  * The name of the command as specified in CMakeList.txt.
-  */
-  std::string GetName() const CM_OVERRIDE
-  {
-    return "cmake_host_system_information";
-  }
-
-  cmTypeMacro(cmCMakeHostSystemInformationCommand, cmCommand);
-
 private:
   bool GetValue(cmsys::SystemInformation& info, std::string const& key,
                 std::string& value);
