@@ -8,12 +8,14 @@
 #ifndef cmDynamicLoader_h
 #define cmDynamicLoader_h
 
-#include <cmConfigure.h> // IWYU pragma: keep
+#include "cmConfigure.h"
 
-#include <cmsys/DynamicLoader.hxx>
+#include "cmsys/DynamicLoader.hxx" // IWYU pragma: export
 
 class cmDynamicLoader
 {
+  CM_DISABLE_COPY(cmDynamicLoader)
+
 public:
   // Description:
   // Load a dynamic library into the current process.
@@ -28,10 +30,6 @@ public:
 protected:
   cmDynamicLoader() {}
   ~cmDynamicLoader() {}
-
-private:
-  cmDynamicLoader(const cmDynamicLoader&); // Not implemented.
-  void operator=(const cmDynamicLoader&);  // Not implemented.
 };
 
 #endif
