@@ -16,8 +16,8 @@ bool cmGetTestPropertyCommand::InitialPass(
     return false;
   }
 
-  std::string testName = args[0];
-  std::string var = args[2];
+  std::string const& testName = args[0];
+  std::string const& var = args[2];
   cmTest* test = this->Makefile->GetTest(testName);
   if (test) {
     const char* prop = CM_NULLPTR;
