@@ -3,8 +3,15 @@
 #ifndef cmIncludeCommand_h
 #define cmIncludeCommand_h
 
+#include "cmConfigure.h"
+
+#include <string>
+#include <vector>
+
 #include "cmCommand.h"
 
+class cmExecutionStatus;
+
 /** \class cmIncludeCommand
  * \brief cmIncludeCommand defines a list of distant
  *  files that can be "included" in the current list file.
@@ -25,18 +32,6 @@ public:
    */
   bool InitialPass(std::vector<std::string> const& args,
                    cmExecutionStatus& status) CM_OVERRIDE;
-
-  /**
-   * This determines if the command is invoked when in script mode.
-   */
-  bool IsScriptable() const CM_OVERRIDE { return true; }
-
-  /**
-   * The name of the command as specified in CMakeList.txt.
-   */
-  std::string GetName() const CM_OVERRIDE { return "include"; }
-
-  cmTypeMacro(cmIncludeCommand, cmCommand);
 };
 
 #endif
