@@ -6,8 +6,8 @@
 #include "cmSystemTools.h"
 #include "cmVersion.h"
 
+#include "cmsys/FStream.hxx"
 #include <algorithm>
-#include <cmsys/FStream.hxx>
 #include <ctype.h>
 #include <iterator>
 #include <stddef.h>
@@ -80,7 +80,7 @@ void cmRST::ProcessModule(std::istream& is)
     if (!rst.empty() && rst != "#") {
       // Bracket mode: check for end bracket
       std::string::size_type pos = line.find(rst);
-      if (pos == line.npos) {
+      if (pos == std::string::npos) {
         this->ProcessLine(line);
       } else {
         if (line[0] != '#') {
@@ -96,14 +96,14 @@ void cmRST::ProcessModule(std::istream& is)
         if (line == "#") {
           this->ProcessLine("");
           continue;
-        } else if (line.substr(0, 2) == "# ") {
-          this->ProcessLine(line.substr(2, line.npos));
-          continue;
-        } else {
-          rst = "";
-          this->Reset();
-          this->OutputLinePending = true;
         }
+        if (line.substr(0, 2) == "# ") {
+          this->ProcessLine(line.substr(2));
+          continue;
+        }
+        rst = "";
+        this->Reset();
+        this->OutputLinePending = true;
       }
       if (line == "#.rst:") {
         rst = "#";
@@ -156,8 +156,8 @@ void cmRST::ProcessLine(std::string const& line)
                        isspace(line[2]))) {
     this->Reset();
     this->Markup =
-      (line.find_first_not_of(" \t", 2) == line.npos ? MarkupEmpty
-                                                     : MarkupNormal);
+      (line.find_first_not_of(" \t", 2) == std::string::npos ? MarkupEmpty
+                                                             : MarkupNormal);
     if (this->CMakeDirective.find(line)) {
       // Output cmake domain directives and their content normally.
       this->NormalLine(line);
@@ -252,7 +252,7 @@ void cmRST::OutputLine(std::string const& line_in, bool inlineMarkup)
       // no explicit "(...)" then add "()" to the text.
       if (this->CMakeRole.match(2) == "command" &&
           this->CMakeRole.match(5).empty() &&
-          text.find_first_of("()") == text.npos) {
+          text.find_first_of("()") == std::string::npos) {
         text += "()";
       }
       this->OS << "``" << text << "``";
