@@ -3,16 +3,21 @@
 #ifndef cmSubdirDependsCommand_h
 #define cmSubdirDependsCommand_h
 
+#include "cmConfigure.h"
+
+#include <string>
+#include <vector>
+
 #include "cmCommand.h"
 
+class cmExecutionStatus;
+
 class cmSubdirDependsCommand : public cmCommand
 {
 public:
   cmCommand* Clone() CM_OVERRIDE { return new cmSubdirDependsCommand; }
   bool InitialPass(std::vector<std::string> const& args,
                    cmExecutionStatus& status) CM_OVERRIDE;
-  std::string GetName() const CM_OVERRIDE { return "subdir_depends"; }
-  cmTypeMacro(cmSubdirDependsCommand, cmCommand);
 };
 
 #endif
