@@ -46,7 +46,20 @@ from sphinx.directives import ObjectDescription
 from sphinx.domains import Domain, ObjType
 from sphinx.roles import XRefRole
 from sphinx.util.nodes import make_refnode
-from sphinx import addnodes, version_info
+from sphinx import addnodes
+
+# Needed for checking if Sphinx version is >= 1.4.
+# See https://github.com/sphinx-doc/sphinx/issues/2673
+old_sphinx = False
+
+try:
+    from sphinx import version_info
+    if version_info < (1, 4):
+        old_sphinx = True
+except ImportError:
+    # The `sphinx.version_info` tuple was added in Sphinx v1.2:
+    old_sphinx = True
+
 
 class CMakeModule(Directive):
     required_arguments = 1
@@ -124,7 +137,7 @@ class _cmake_index_entry:
 
     def __call__(self, title, targetid, main = 'main'):
         # See https://github.com/sphinx-doc/sphinx/issues/2673
-        if version_info < (1, 4):
+        if old_sphinx:
             return ('pair', u'%s ; %s' % (self.desc, title), targetid, main)
         else:
             return ('pair', u'%s ; %s' % (self.desc, title), targetid, main, None)
